pub enum Action<A: ActionExt = NullActionExt> {
Show 52 variants
Select,
Deselect,
Toggle,
CycleAll,
ClearSelections,
Accept,
Quit(i32),
ToggleWrap,
Up(u16),
Down(u16),
Pos(i32),
PageDown,
PageUp,
CyclePreview,
Preview(String),
Help(String),
SetPreview(Option<u8>),
SwitchPreview(Option<u8>),
TogglePreviewWrap,
PreviewUp(u16),
PreviewDown(u16),
PreviewHalfPageUp,
PreviewHalfPageDown,
HScroll(i8),
PreviewHScroll(i8),
PreviewScroll(i8),
PreviewJump,
Column(usize),
CycleColumn,
ColumnLeft,
ColumnRight,
ScrollLeft,
ScrollRight,
Execute(String),
Become(String),
Reload(String),
Print(String),
ForwardChar,
BackwardChar,
ForwardWord,
BackwardWord,
DeleteChar,
DeleteWord,
DeleteLineStart,
DeleteLineEnd,
Cancel,
SetQuery(String),
QueryPos(i32),
Char(char),
Redraw,
Custom(A),
Overlay(usize),
}Expand description
Variants
Select
Add item to selections
Deselect
Remove item from selections
Toggle
Toggle item in selections
CycleAll
Toggle all selections
ClearSelections
Clear all selections
Accept
Accept current selection
Quit(i32)
Quit with code
ToggleWrap
Toggle wrap
Up(u16)
Move selection index up
Down(u16)
Move selection index down
Pos(i32)
PageDown
PageUp
CyclePreview
Cycle preview layouts
Preview(String)
Show/hide preview for selection
Help(String)
Show help in preview
SetPreview(Option<u8>)
Set preview layout; None restores the command of the current layout.
SwitchPreview(Option<u8>)
Switch or toggle preview: If an index is provided and the index is already current, the preview is hidden.
TogglePreviewWrap
Toggle wrap in preview
PreviewUp(u16)
Scroll preview up
PreviewDown(u16)
Scroll preview down
PreviewHalfPageUp
Scroll preview half page up in rows. If wrapping is enabled, the visual distance may exceed half a page.
PreviewHalfPageDown
Scroll preview half page down in rows. If wrapping is enabled, the visual distance may exceed half a page.
HScroll(i8)
Horizontally scroll either results or preview based on mouse location and wrapping configuration. (TODO) 0 to reset.
PreviewHScroll(i8)
Persistent horizontal scroll 0 to reset.
PreviewScroll(i8)
Persistent single-line vertical scroll 0 to reset.
PreviewJump
Jump between start, end, last, and initial locations. (unimplemented).
Column(usize)
Set active column
CycleColumn
Cycle columns
ColumnLeft
ColumnRight
ScrollLeft
ScrollRight
Execute(String)
Execute command and continue
Become(String)
Exit and become
Reload(String)
Reload matcher/worker
Print(String)
Print via handler
ForwardChar
Move cursor forward char
BackwardChar
Move cursor backward char
ForwardWord
Move cursor forward word
BackwardWord
Move cursor backward word
DeleteChar
Delete char
DeleteWord
Delete word
DeleteLineStart
Delete to start of line
DeleteLineEnd
Delete to end of line
Cancel
Clear input
SetQuery(String)
Set input query
QueryPos(i32)
Set query cursor pos
Char(char)
Insert char into input
Redraw
Force redraw
Custom(A)
Custom action
Overlay(usize)
Activate the nth overlay