KeyCombination

Struct KeyCombination 

pub struct KeyCombination {
    pub codes: OneToThree<KeyCode>,
    pub modifiers: KeyModifiers,
}
A Key combination wraps from one to three standard keys with optional modifiers (ctrl, alt, shift).

Fields

codes: OneToThree<KeyCode>modifiers: KeyModifiers

Implementations

Source

impl KeyCombination

pub fn new<C>(codes: C, modifiers: KeyModifiers) -> KeyCombination
where C: Into<OneToThree<KeyCode>>,

Create a new KeyCombination from one to three keycodes and a set of modifiers

pub const fn one_key(code: KeyCode, modifiers: KeyModifiers) -> KeyCombination

Create a new KeyCombination from one keycode and a set of modifiers

pub const fn is_ansi_compatible(self) -> bool

Ansi terminals don’t manage key press/release/repeat, so they don’t allow to determine whether 2 keys are pressed at the same time. This means a combination involving several key codes can’t be distiguished from a sequences of combinations involving a single key code. For this reason, only combinations involving a single key code are considered “ansi compatible”

pub fn normalized(self) -> KeyCombination

Return a normailzed version of the combination.

Fix the case of the code to uppercase if the shift modifier is present. Add the SHIFT modifier if one code is uppercase.

This allows direct comparisons with the fields of crossterm::event::KeyEvent whose code is uppercase when the shift modifier is present. And supports the case where the modifier isn’t mentionned but the key is uppercase.

pub const fn as_letter(self) -> Option<char>

return the raw char if the combination is a letter event