Module config

Module config 

Config Types. See src/bin/mm/config.rs for an example

Structs

AutoscrollSettings
BorderSetting
ColumnName
ColumnSetting
ColumnsConfig
Count
DisplayConfig
ExitConfig
Exit conditions of the render loop.
HelpColorConfig
Help coloring
InputConfig
The query (input) bar ui.
MatcherConfig
Settings unrelated to event loop/picker_ui.
NucleoMatcherConfig
OverlayConfig
OverlayLayoutSettings
Padding
Percentage
PreviewConfig
Example
PreviewInitialSetting
Determines the initial scroll offset of the preview window.
PreviewLayout
PreviewSetting
PreviewerConfig
RenderConfig
The ui config.
ResultsConfig
StartConfig
Configures how input is fed to to the worker(s).
StatusConfig
StringValue
TerminalConfig
Terminal settings.
TerminalLayoutSettings
UiConfig
The container ui.
WorkerConfig
“Input/output specific”. Configures the matchmaker worker.

Enums

CursorSetting
HorizontalSeparator
RowConnectionStyle
ShowCondition
Side
Split
StringOrVec

Functions

deserialize_string_or_char_as_double_width