pub struct AutoscrollSettings {
pub initial_preserved: usize,
pub enabled: bool,
pub context: usize,
pub end: bool,
}Fields
initial_preserved: usizeNumber of characters at the start of the line to always keep visible.
enabled: boolEnable/disable horizontal autoscroll.
context: usizeNumber of characters to show around the match.
end: boolWhether to autoscroll to the end of the line.