BorderSetting

Struct BorderSetting 

pub struct BorderSetting {
    pub type: BorderType,
    pub color: Color,
    pub sides: Option<Borders>,
    pub padding: Padding,
    pub title: String,
    pub title_modifier: Modifier,
    pub bg: Color,
}

Fields

type: BorderTypecolor: Colorsides: Option<Borders>

Given as sides joined by |. i.e.: sides = "TOP | BOTTOM"`` sides = “ALL”` When omitted, this either ALL or the side that sits between results and the corresponding layout if either padding or type are specified, otherwise NONE.

An empty string enforces no sides: sides = ""

padding: Padding

Supply as either 1, 2, or 4 numbers for:

  • Same padding on all sides
  • Vertical and horizontal padding values
  • Top, Right, Bottom, Left padding values

respectively.

title: Stringtitle_modifier: Modifierbg: Color

Implementations

Source

impl BorderSetting

pub fn as_block(&self) -> Block<'_>

pub fn sides(&self) -> Borders

pub fn as_static_block(&self) -> Block<'static>

pub fn is_empty(&self) -> bool

pub fn height(&self) -> u16

pub fn width(&self) -> u16

pub fn left(&self) -> u16

pub fn top(&self) -> u16