pub struct PreviewScrollSetting {
pub index: Option<String>,
pub offset: isize,
pub percentage: Percentage,
pub header_lines: usize,
}Expand description
Determines the initial scroll offset of the preview window.
Fields
index: Option<String>Extract the initial display index n of the preview window from this column.
n lines are skipped after the header lines are consumed.
offset: isizeFor adjusting the initial scroll index.
percentage: PercentageHow far from the bottom of the preview window the scroll offset should appear.
header_lines: usizeKeep the top N lines as the fixed header so that they are always visible.