pub struct ResultsConfig {Show 25 fields
pub border: BorderSetting,
pub multi_prefix: String,
pub default_prefix: String,
pub multi: bool,
pub style: StyleSetting,
pub inactive: StyleSetting,
pub inactive_current: StyleSetting,
pub match_style: StyleSetting,
pub current: StyleSetting,
pub row_connection: RowConnectionStyle,
pub scroll_wrap: bool,
pub scroll_padding: u16,
pub reverse: Option<bool>,
pub wrap: bool,
pub min_wrap_width: u16,
pub autoscroll: AutoscrollSettings,
pub column_spacing: Count,
pub current_prefix: String,
pub max_height: usize,
pub show_skipped: bool,
pub vscroll_current_only: bool,
pub right_align_last: bool,
pub stacked_columns: bool,
pub separator: HorizontalSeparator,
pub separator_style: StyleSetting,
}Fields
border: BorderSettingmulti_prefix: Stringdefault_prefix: Stringmulti: boolEnable selections
style: StyleSettinginactive: StyleSettinginactive_current: StyleSettingmatch_style: StyleSettingcurrent: StyleSettingcurrent item style
row_connection: RowConnectionStyleHow the styles are applied across the row: Disjoint: Styles are applied per column. Capped: The inactive styles are applied per row, and the active styles applied on the active column. Full: Inactive column styles are ignored, the current style is applied on the current row.
scroll_wrap: boolscroll_padding: u16reverse: Option<bool>wrap: boolmin_wrap_width: u16autoscroll: AutoscrollSettingscolumn_spacing: Countcurrent_prefix: Stringmax_height: usizeMaximum row height. VScroll/Preview can still be used to view the whole result.
show_skipped: boolvscroll_current_only: boolAlways false if max_height is set
right_align_last: boolstacked_columns: boolseparator: HorizontalSeparatorseparator_style: StyleSettingTrait Implementations
Sourceimpl Clone for ResultsConfig
impl Clone for ResultsConfig
Sourcefn clone(&self) -> ResultsConfig
fn clone(&self) -> ResultsConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResultsConfig
impl Debug for ResultsConfig
Sourceimpl Default for ResultsConfig
impl Default for ResultsConfig
Sourceimpl<'de> Deserialize<'de> for ResultsConfigwhere
ResultsConfig: Default,
impl<'de> Deserialize<'de> for ResultsConfigwhere
ResultsConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ResultsConfig
impl PartialEq for ResultsConfig
Sourceimpl Serialize for ResultsConfig
impl Serialize for ResultsConfig
impl StructuralPartialEq for ResultsConfig