pub struct StartConfig {
pub input_separator: Option<char>,
pub output_separator: Option<String>,
pub output_template: Option<String>,
pub command: String,
pub sync: bool,
}Expand description
Configures how input is fed to to the worker(s).
Does not deny unknown fields.
Fields
input_separator: Option<char>output_separator: Option<String>output_template: Option<String>Format string to print accepted items as.
command: StringDefault command to execute when stdin is not being read.
sync: boolTrait Implementations
Sourceimpl Clone for StartConfig
impl Clone for StartConfig
Sourcefn clone(&self) -> StartConfig
fn clone(&self) -> StartConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StartConfig
impl Debug for StartConfig
Sourceimpl Default for StartConfig
impl Default for StartConfig
Sourcefn default() -> StartConfig
fn default() -> StartConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StartConfigwhere
StartConfig: Default,
impl<'de> Deserialize<'de> for StartConfigwhere
StartConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StartConfig
impl PartialEq for StartConfig
Sourceimpl Serialize for StartConfig
impl Serialize for StartConfig
impl StructuralPartialEq for StartConfig