pub struct WorkerConfig {
pub columns: ColumnsConfig,
pub trim: bool,
pub sort_threshold: u32,
pub ansi: bool,
pub raw: bool,
pub track: bool,
pub reverse: bool,
}Expand description
“Input/output specific”. Configures the matchmaker worker.
Does not deny unknown fields.
Fields
columns: ColumnsConfigHow columns are parsed from input lines
trim: boolTrim the input
sort_threshold: u32How “stable” the results are. Higher values prioritize the initial ordering.
ansi: boolWhether to parse ansi sequences from input
raw: boolTODO: Enable raw mode where non-matching items are also displayed in a dimmed color.
track: boolTODO: Track the current selection when the result list is updated.
reverse: boolTODO: Reverse the order of the input