MatchError

Enum MatchError 

#[non_exhaustive]
pub enum MatchError { Abort(i32), EventLoopClosed, Become(String), TUIError(String), NoMatch, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Abort(i32)



EventLoopClosed

Event loop closed



Become(String)



TUIError(String)

Critical error in TUI initialization/execution.



NoMatch

Specifically for crate::MatchResultExt::first, this error should not arise in normal execution unless cursor is disabled when the render loop exits with success status. The cursor is never disabled in the binary crate.