Module event

Module event 

Structs

EventLoop

Functions

write_to_file
Spawns a thread that writes content to path atomically using a temp file. Returns the JoinHandle so you can wait for it if desired.

Type Aliases

BindSender
EventSender
RenderSender