pub fn make_previewer<T: SSS, S: Selection + 'static>(
mm: &mut Matchmaker<T, S>,
previewer_config: PreviewerConfig,
formatter: AttachmentFormatter<T, S>,
help_str: Text<'static>,
) -> PreviewerExpand description
Causes the program to display a preview of the active result.
The Previewer can be connected to Matchmaker using PickOptions::previewer