Module nucleo

Module nucleo 

Re-exports

pub use nucleo;
pub use variants::*;

Modules

backend
This module provides the backend implementations for different terminal libraries.
buffer
A module for the Buffer and Cell types.
injector
layout
Layout and positioning in terminal user interfaces.
query
style
style contains the primitives used to control how your user interface will look.
symbols
Symbols and markers for drawing various widgets.
text
Primitives for styled text.
variants

Structs

Buffer
A buffer that maps to the desired content of the terminal after the draw call
Column
ColumnOptions
CrosstermBackend
A Backend implementation that uses Crossterm to render to the terminal.
Frame
A consistent view into the terminal state for rendering a single frame.
Indexed
Layout
The primary layout engine for dividing terminal space using constraints and direction.
Line
A line of text, consisting of one or more Spans.
Margin
Represents spacing around rectangular areas.
Masked
A wrapper around a string that is masked when displayed.
Modifier
Modifier changes the way a piece of text is displayed.
Position
Position in the terminal coordinate system.
Rect
A rectangular area in the terminal.
Segmented
This struct implements ColumnIndexable, and can instantiate a worker with columns.
Size
A simple size struct for representing dimensions in the terminal.
Span
Represents a part of a line that is contiguous and where all characters share the same style.
Status
Style
Style lets you control the main characteristics of the displayed elements.
Terminal
An interface to interact and draw Frames on the user’s terminal.
Text
A string split over one or more lines.
Worker
Worker: can instantiate, push, and get results. A view into computation.

Enums

Color
ANSI Color
Constraint
A constraint that defines the size of a layout element.
Direction
Defines the direction of a layout.
HorizontalAlignment
Horizontal content alignment within a layout area.
VerticalAlignment
Vertical content alignment within a layout area.
WorkerError

Traits

Backend
The Backend trait provides an abstraction over different terminal libraries. It defines the methods required to draw content, manipulate the cursor, and clear the terminal screen.
BlockExt
An extension trait for Block that provides some convenience methods.
FromCrossterm
A trait for converting a Crossterm type to a Ratatui type.
IntoCrossterm
A trait for converting a Ratatui type to a Crossterm type.
SegmentableItem
StatefulWidget
A StatefulWidget is a widget that can take advantage of some local state to remember things between two draw calls.
Stylize
An extension trait for styling objects.
Widget
A Widget is a type that can be drawn on a Buffer in a given Rect.

Type Aliases

Alignment
A type alias for HorizontalAlignment.
WorkerResults
A vec of ItemResult, each ItemResult being the Column Texts of the Item, and Item