ClearType

Enum ClearType 

pub enum ClearType {
    All,
    AfterCursor,
    BeforeCursor,
    CurrentLine,
    UntilNewLine,
}
Enum representing the different types of clearing operations that can be performed on the terminal screen.

Variants



All

Clear the entire screen.



AfterCursor

Clear everything after the cursor.



BeforeCursor

Clear everything before the cursor.



CurrentLine

Clear the current line.



UntilNewLine

Clear everything from the cursor until the next newline.