pub enum Direction {
Horizontal,
Vertical,
}Expand description
Defines the direction of a layout.
This enumeration is used with Layout to specify whether layout
segments should be arranged horizontally or vertically.
Horizontal: Layout segments are arranged side by side (left to right)Vertical: Layout segments are arranged top to bottom (default)
For comprehensive layout documentation and examples, see the layout module.
Variants
Horizontal
Layout segments are arranged side by side (left to right).
Vertical
Layout segments are arranged top to bottom (default).
Implementations