HorizontalAlignment

Enum HorizontalAlignment 

pub enum HorizontalAlignment {
    Left,
    Center,
    Right,
}
Horizontal content alignment within a layout area.

Prior to Ratatui 0.30.0, this type was named Alignment. In Ratatui 0.30.0, the name was changed to HorizontalAlignment to make it more descriptive. The old name is still available as an alias for backwards compatibility.

This type is used throughout Ratatui to control how content is positioned horizontally within available space. It’s commonly used with widgets to control text alignment, but can also be used in layout calculations.

For comprehensive layout documentation and examples, see the layout module.

Variants



Left



Center



Right