Indexed

Struct Indexed 

pub struct Indexed<T> {
    pub index: u32,
    pub inner: T,
}

Fields

index: u32inner: T

Implementations

Source

impl<T: Clone> Indexed<T>

pub fn identifier(&self) -> (u32, T)

Matchmaker requires a way to identify and store selected items from their references in the nucleo matcher. This method simply identifies them by their insertion index and stores the clones of the items.

Source

impl<T> Indexed<T>

pub fn dummy_identifier(&self) -> (u32, ())

Matchmaker requires a way to identify and store selected items from their references in the nucleo matcher. This method simply identifies them by their insertion index and is intended when the output type is not needed (i.e. externally managed).