pub struct Position {
pub x: u16,
pub y: u16,
}Expand description
Position in the terminal coordinate system.
The position is relative to the top left corner of the terminal window, with the top left corner being (0, 0). The x axis is horizontal increasing to the right, and the y axis is vertical increasing downwards.
Position is used throughout the layout system to represent specific points in the terminal.
It can be created from coordinates, tuples, or extracted from rectangular areas.
Construction
Conversion
from((u16, u16))- Create from(u16, u16)tuplefrom(Rect)- Create fromRect(uses top-left corner)- [
into((u16, u16))] - Convert to(u16, u16)tuple
Movement
offset- Move by anOffsetAdd<Offset>andSub<Offset>- Shift by offsets with clampingAddAssign<Offset>andSubAssign<Offset>- In-place shifting
Examples
use ratatui_core::layout::{Offset, Position, Rect};
// the following are all equivalent
let position = Position { x: 1, y: 2 };
let position = Position::new(1, 2);
let position = Position::from((1, 2));
let position = Position::from(Rect::new(1, 2, 3, 4));
// position can be converted back into the components when needed
let (x, y) = position.into();
// movement by offsets
let position = Position::new(5, 5) + Offset::new(2, -3);
assert_eq!(position, Position::new(7, 2));For comprehensive layout documentation and examples, see the layout module.
Fields
x: u16The x coordinate of the position
The x coordinate is relative to the left edge of the terminal window, with the left edge being 0.
y: u16The y coordinate of the position
The y coordinate is relative to the top edge of the terminal window, with the top edge being 0.
Implementations