Worker

Struct Worker 

pub struct Worker<T>
where T: SSS,
{ /* private fields */ }
Worker: can instantiate, push, and get results. A view into computation.

Additionally, the worker can affect the computation via find and restart.

Implementations

Source

impl<T: SSS> Worker<T>

pub fn make_format_fn<const QUOTE: bool>( &self, blank_format: impl Fn(&T) -> Cow<'_, str> + SSS, ) -> RenderFn<T>

Returns a function which templates a string given an item using the column functions

Source

impl<T: Render + SSS> Worker<Indexed<T>>

pub fn new_single_column() -> Self

Create a new worker over items which are displayed in the picker as exactly their as_str representation.

Examples found in repository?
examples/ripgrep.rs (line 5)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
More examples
Hide additional examples
examples/pick_1.rs (line 7)
4pub async fn mm_get<T: SSS + Render + Clone>(
5    items: impl IntoIterator<Item = T>,
6) -> Result<T, MatchError> {
7    let worker = Worker::new_single_column();
8    worker.append(items);
9    let selector = Selector::new(Indexed::identifier);
10    let mm = Matchmaker::new(worker, selector);
11
12    mm.pick_default().await.first()
13}
examples/basic.rs (line 8)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let selector = Selector::new(Indexed::identifier);
11    let mm = Matchmaker::new(worker, selector);
12
13    match mm.pick_default().await {
14        Ok(v) => {
15            println!("{}", v[0]);
16        }
17        Err(err) => match err {
18            MatchError::Abort(1) => {
19                eprintln!("cancelled");
20            }
21            _ => {
22                eprintln!("Error: {err}");
23            }
24        },
25    }
26
27    Ok(())
28}
pub fn append(&self, items: impl IntoIterator<Item = T>) -> u32

A convenience method to initialize data. Note that it is clearly unsound to use this concurrently with other workers, or to subsequently push with an IndexedInjector.

Examples found in repository?
examples/ripgrep.rs (line 7)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
More examples
Hide additional examples
examples/pick_1.rs (line 8)
4pub async fn mm_get<T: SSS + Render + Clone>(
5    items: impl IntoIterator<Item = T>,
6) -> Result<T, MatchError> {
7    let worker = Worker::new_single_column();
8    worker.append(items);
9    let selector = Selector::new(Indexed::identifier);
10    let mm = Matchmaker::new(worker, selector);
11
12    mm.pick_default().await.first()
13}
examples/basic.rs (line 9)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let selector = Selector::new(Indexed::identifier);
11    let mm = Matchmaker::new(worker, selector);
12
13    match mm.pick_default().await {
14        Ok(v) => {
15            println!("{}", v[0]);
16        }
17        Err(err) => match err {
18            MatchError::Abort(1) => {
19                eprintln!("cancelled");
20            }
21            _ => {
22                eprintln!("Error: {err}");
23            }
24        },
25    }
26
27    Ok(())
28}
Source

impl<T> Worker<T>
where T: ColumnIndexable + SSS,

pub fn new_indexable<I, S>(column_names: I) -> Self
where I: IntoIterator<Item = S>, S: Into<Arc<str>>,

Create a new worker over indexable items, whose columns as displayed in the picker correspond to indices according to the relative order of the column names given to this function.

Source

impl<T> Worker<T>
where T: SSS,

pub fn new( columns: impl IntoIterator<Item = Column<T>>, default_column: usize, ) -> Self

Column names must be distinct!

pub fn injector(&self) -> WorkerInjector<T>

pub fn find(&mut self, line: &str)

pub fn shutdown(&mut self)

pub fn restart(&mut self, clear_snapshot: bool)

pub fn get_nth(&self, n: u32) -> Option<&T>

pub fn new_snapshot(nucleo: &mut Nucleo<T>) -> (&Snapshot<T>, Status)

pub fn raw_results( &self, ) -> impl ExactSizeIterator<Item = &T> + DoubleEndedIterator + '_

pub fn counts(&self) -> (u32, u32)

matched item count, total item count

Source

impl<T: SSS> Worker<T>

pub fn results( &mut self, start: u32, end: u32, width_limits: &[u16], highlight_style: Style, matcher: &mut Matcher, ) -> (WorkerResults<'_, T>, Vec<u16>, Status)