StyledGrapheme

Struct StyledGrapheme 

pub struct StyledGrapheme<'a> {
    pub symbol: &'a str,
    pub style: Style,
}
A grapheme associated to a style. Note that, although StyledGrapheme is the smallest divisible unit of text, it actually is not a member of the text type hierarchy (Text -> Line -> Span). It is a separate type used mostly for rendering purposes. A Span consists of components that can be split into StyledGraphemes, but it does not contain a collection of StyledGraphemes.

Fields

symbol: &'a strstyle: Style

Implementations

Source

impl<'a> StyledGrapheme<'a>

pub fn new<S>(symbol: &'a str, style: S) -> StyledGrapheme<'a>
where S: Into<Style>,

Creates a new StyledGrapheme with the given symbol and style.

style accepts any type that is convertible to Style (e.g. Style, Color, or your own type that implements Into<Style>).

pub fn is_whitespace(&self) -> bool