pub enum Effect {
}Variants
ClearPreviewSet
Header(Text<'static>)
ClearHeader
ClearSelections
RevalidateSelectons
Reload
Reload the nucleo matcher Note that the reload interrupt handler is NOT triggered if this is produced from a dynamic handler
Prompt(Span<'static>)
Input((String, u16))
Set the input ui contents and cursor
RestoreInputPrefix
DisableCursor(bool)
SetIndex(u32)
TrySync