pub struct State {
pub preview_set_payload: Option<String>,
pub preview_payload: String,
pub should_quit: bool,
pub should_quit_nomatch: bool,
/* private fields */
}Fields
preview_set_payload: Option<String>The String passed to SetPreview
preview_payload: StringThe payload left by crate::action::Action::Preview
should_quit: boolSetting this to true finishes the picker with the contents of Selector.
If Selector is disabled, the picker finishes with the current item.
If there are no items to finish with, the picker finishes with crate::errors::MatchError::Abort(0).
should_quit_nomatch: boolSetting this to true finishes the picker with crate::MatchError::NoMatch.
Implementations
Sourceimpl State
impl State
pub fn new() -> Self
pub fn contains(&self, event: Event) -> bool
pub fn payload(&self) -> &String
pub fn interrupt(&self) -> Interrupt
pub fn set_interrupt(&mut self, interrupt: Interrupt, payload: String)
pub fn clear_interrupt(&mut self)
pub fn insert(&mut self, event: Event)
pub fn overlay_index(&self) -> Option<usize>
pub fn preview_set_payload(&self) -> Option<String>
pub fn preview_payload(&self) -> &String
pub fn stashed_preview_visibility(&self) -> Option<bool>