Matchmaker

Struct Matchmaker 

pub struct Matchmaker<T: SSS, S: Selection = T> {
    pub worker: Worker<T>,
    pub render_config: RenderConfig,
    pub tui_config: TerminalConfig,
    pub exit_config: ExitConfig,
    pub selector: Selector<T, S>,
    pub event_handlers: EventHandlers<T, S>,
    pub interrupt_handlers: InterruptHandlers<T, S>,
}
The main entrypoint of the library. To use:

  1. create your worker (T -> Columns)
  2. Determine your identifier
  3. Instantiate this with Matchmaker::new_from_raw(..)
  4. Register your handlers 4.5 Start and connect your previewer
  5. Call mm.pick() or mm.pick_with_matcher(&mut matcher)

Fields

worker: Worker<T>render_config: RenderConfigtui_config: TerminalConfigexit_config: ExitConfigselector: Selector<T, S>event_handlers: EventHandlers<T, S>interrupt_handlers: InterruptHandlers<T, S>

Implementations

Source

impl Matchmaker<Indexed<Segmented<Either<String, Text<'static>>>>, Segmented<Either<String, Text<'static>>>>

pub fn new_from_config( render_config: RenderConfig, tui_config: TerminalConfig, worker_config: WorkerConfig, exit_config: ExitConfig, ) -> (Self, ConfigInjector, OddEnds)

Creates a new Matchmaker from a config::BaseConfig.

Source

impl<T: SSS, S: Selection> Matchmaker<T, S>

pub fn new(worker: Worker<T>, selector: Selector<T, S>) -> Self

Examples found in repository?
examples/pick_1.rs (line 8)
4pub async fn mm_get<T: SSS + Render + Clone>(items: impl IntoIterator<Item = T>) -> Result<T> {
5    let worker = Worker::new_single_column();
6    worker.append(items);
7    let selector = Selector::new(Indexed::identifier).disabled();
8    let mm = Matchmaker::new(worker, selector);
9
10    mm.pick_default().await.first()
11}
More examples
Hide additional examples
examples/basic.rs (line 11)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let selector = Selector::new(Indexed::identifier);
11    let mm = Matchmaker::new(worker, selector);
12
13    match mm.pick_default().await {
14        Ok(v) => {
15            println!("{}", v[0]);
16        }
17        Err(err) => match err {
18            MatchError::Abort(1) => {
19                eprintln!("cancelled");
20            }
21            _ => {
22                eprintln!("Error: {err}");
23            }
24        },
25    }
26
27    Ok(())
28}
pub fn config_render(&mut self, render: RenderConfig) -> &mut Self

Configure the UI

pub fn config_tui(&mut self, tui: TerminalConfig) -> &mut Self

Configure the TUI

pub fn config_exit(&mut self, exit: ExitConfig) -> &mut Self

Configure exit conditions

pub fn register_event_handler<F>(&mut self, event: Event, handler: F)
where F: Fn(&mut MMState<'_, '_, T, S>, &Event) + 'static,

Register a handler to listen on Events

pub fn register_boxed_event_handler( &mut self, event: Event, handler: DynamicMethod<T, S, Event>, )

Register a boxed handler to listen on Events

pub fn register_interrupt_handler<F>( &mut self, interrupt: Interrupt, handler: F, )
where F: Fn(&mut MMState<'_, '_, T, S>) + 'static,

Register a handler to listen on Interrupts

pub fn register_boxed_interrupt_handler( &mut self, variant: Interrupt, handler: BoxedHandler<T, S>, )

Register a boxed handler to listen on Interrupts

pub async fn pick<A: ActionExt>( self, builder: PickOptions<'_, T, S, A>, ) -> Result<Vec<S>>

The main method of the Matchmaker. It starts listening for events and renders the TUI with ratatui. It successfully returns with all the selected items selected when the Accept action is received.

pub async fn pick_default(self) -> Result<Vec<S>>

Examples found in repository?
examples/pick_1.rs (line 10)
4pub async fn mm_get<T: SSS + Render + Clone>(items: impl IntoIterator<Item = T>) -> Result<T> {
5    let worker = Worker::new_single_column();
6    worker.append(items);
7    let selector = Selector::new(Indexed::identifier).disabled();
8    let mm = Matchmaker::new(worker, selector);
9
10    mm.pick_default().await.first()
11}
More examples
Hide additional examples
examples/basic.rs (line 13)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let selector = Selector::new(Indexed::identifier);
11    let mm = Matchmaker::new(worker, selector);
12
13    match mm.pick_default().await {
14        Ok(v) => {
15            println!("{}", v[0]);
16        }
17        Err(err) => match err {
18            MatchError::Abort(1) => {
19                eprintln!("cancelled");
20            }
21            _ => {
22                eprintln!("Error: {err}");
23            }
24        },
25    }
26
27    Ok(())
28}
Source

impl<T: SSS, S: Selection> Matchmaker<T, S>

pub fn register_print_handler( &mut self, print_handle: AppendOnly<String>, output_separator: String, formatter: Arc<RenderFn<T>>, )

Causes Action::Print to print to stdout.

pub fn register_execute_handler(&mut self, formatter: Arc<RenderFn<T>>)

Causes Action::Execute to cause the program to execute the program specified by its payload. Note:

  • not intended for direct use.
  • Assumes preview and cmd formatter are the same.
pub fn register_become_handler(&mut self, formatter: Arc<RenderFn<T>>)

Causes Action::Become to cause the program to become the program specified by its payload. Note:

  • not intended for direct use.
  • Assumes preview and cmd formatter are the same.