pub struct DisplayUI {
pub show: bool,
pub config: DisplayConfig,
/* private fields */
}Fields
show: boolconfig: DisplayConfigImplementations
Sourceimpl DisplayUI
impl DisplayUI
pub fn new(config: DisplayConfig) -> Self
pub fn update_width(&mut self, width: u16)
pub fn height(&self) -> u16
Sourcepub fn set(&mut self, text: impl Into<Text<'static>>, keep_header: bool)
pub fn set(&mut self, text: impl Into<Text<'static>>, keep_header: bool)
Set text and visibility. Compute wrapped height.
pub fn clear(&mut self, keep_header: bool)
pub fn header_table(&mut self, table: HeaderTable)
pub fn make_display( &mut self, result_indentation: u16, widths: Vec<u16>, col_spacing: u16, ) -> Table<'_>
Sourcepub fn make_full_width_row(&self, result_indentation: u16) -> Paragraph<'_>
pub fn make_full_width_row(&self, result_indentation: u16) -> Paragraph<'_>
Draw in the same area as display when self.single() to produce a full width row over the table area