pub struct InputUI {
pub input: String,
pub config: InputConfig,
pub prompt: Span<'static>,
pub width: u16,
/* private fields */
}Fields
input: Stringconfig: InputConfigprompt: Span<'static>width: u16Implementations
Sourceimpl InputUI
impl InputUI
pub fn new(config: InputConfig) -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn cursor_offset(&self, rect: &Rect) -> Position
pub fn cursor_offset(&self, rect: &Rect) -> Position
Given a rect the widget is rendered with, produce the absolute position the cursor is rendered at.
pub fn push_char(&mut self, c: char)
pub fn push_str(&mut self, content: &str)
pub fn set(&mut self, input: impl Into<Option<String>>, cursor: u16)
pub fn update_width(&mut self, width: u16)
pub fn scroll_to_cursor(&mut self)
pub fn set_at_visual_offset(&mut self, visual_offset: u16)
pub fn cancel(&mut self)
pub fn reset_prompt(&mut self)
pub fn forward_char(&mut self)
pub fn backward_char(&mut self)
pub fn forward_word(&mut self)
pub fn backward_word(&mut self)
pub fn delete(&mut self)
pub fn delete_word(&mut self)
pub fn delete_line_start(&mut self)
pub fn delete_line_end(&mut self)
pub fn make_input(&self) -> Paragraph<'_>