pub enum Action<A: ActionExt = NullActionExt> {
Show 48 variants
Select,
Deselect,
Toggle,
CycleAll,
ClearAll,
Accept,
Quit(Exit),
CyclePreview,
Preview(String),
Help(String),
SwitchPreview(Option<u8>),
SetPreview(Option<u8>),
ToggleWrap,
ToggleWrapPreview,
Execute(String),
Become(String),
Reload(String),
Print(String),
SetInput(String),
SetHeader(Option<String>),
SetFooter(Option<String>),
SetPrompt(Option<String>),
Column(usize),
CycleColumn,
HistoryUp,
HistoryDown,
ChangePrompt,
ChangeQuery,
ForwardChar,
BackwardChar,
ForwardWord,
BackwardWord,
DeleteChar,
DeleteWord,
DeleteLineStart,
DeleteLineEnd,
Cancel,
InputPos(i32),
Up(Count),
Down(Count),
PreviewUp(Count),
PreviewDown(Count),
PreviewHalfPageUp,
PreviewHalfPageDown,
Pos(i32),
Redraw,
Custom(A),
Overlay(usize),
}Variants
Select
Add item to selections
Deselect
Remove item from selections
Toggle
Toggle item in selections
CycleAll
ClearAll
Accept
Quit(Exit)
CyclePreview
Preview(String)
Help(String)
SwitchPreview(Option<u8>)
SetPreview(Option<u8>)
ToggleWrap
ToggleWrapPreview
Execute(String)
Pauses the tui display and the event loop, and invokes the handler for crate::message::Interrupt::Execute
The remaining actions in the buffer are still processed
Become(String)
Exits the tui and invokes the handler for crate::message::Interrupt::Become
Reload(String)
Restarts the matcher-worker and invokes the handler for crate::message::Interrupt::Reload
Print(String)
Invokes the handler for crate::message::Interrupt::Print
See also: crate::Matchmaker::register_print_handler
SetInput(String)
SetHeader(Option<String>)
SetPrompt(Option<String>)
Column(usize)
CycleColumn
HistoryUp
HistoryDown
ChangePrompt
ChangeQuery
ForwardChar
BackwardChar
ForwardWord
BackwardWord
DeleteChar
DeleteWord
DeleteLineStart
DeleteLineEnd
Cancel
InputPos(i32)
Up(Count)
Down(Count)
PreviewUp(Count)
PreviewDown(Count)
PreviewHalfPageUp
PreviewHalfPageDown
Pos(i32)
Redraw
Custom(A)
Overlay(usize)