Config Types.
See src/bin/mm/config.rs for an example
Structs
- Border
Setting - Column
Setting - Columns
Config - Count
- Display
Config - Exit
Config - Exit conditions of the render loop.
- Format
String - Input
Config - The input bar ui.
- Matcher
Config - Settings unrelated to event loop/picker_ui.
- Nucleo
Matcher Config - Overlay
Config - Overlay
Layout Settings - Percentage
- Preview
Config - Example
- Preview
Layout - Preview
Scroll Setting - Determines the initial scroll offset of the preview window.
- Preview
Setting - Previewer
Config - Render
Config - The ui config.
- Results
Config - Start
Config - Configures how input is fed to to the worker(s).
- Terminal
Config - Terminal settings.
- Terminal
Layout Settings - Terminal
Settings - Toml
Color Config - Help coloring
- UiConfig
- The container ui.
- Worker
Config - “Input/output specific”. Configures the matchmaker worker.