pub struct DisplayConfig {
pub border: BorderSetting,
pub fg: Color,
pub modifier: Modifier,
pub match_indent: bool,
pub wrap: bool,
pub content: Option<StringOrVec>,
pub row_connection_style: RowConnectionStyle,
pub header_lines: usize,
}Fields
border: BorderSettingfg: Colormodifier: Modifiermatch_indent: boolwrap: boolcontent: Option<StringOrVec>row_connection_style: RowConnectionStyleThis setting controls the effective width of the displayed content.
- Full: Effective width is the full ui width.
- Capped: Effective width is the full ui width, but any width exceeding the width of the Results UI is occluded by the preview pane.
- Disjoint: Effective width is same as the Results UI.
Note
The width effect only applies on the footer, and when the content is singular.
header_lines: usizeThis setting controls how many lines are read from the input for display with the header.
Note
This only affects the header and is only implemented in the binary.