Module nucleo

Module nucleo 

Re-exports

pub use variants::*;

Modules

injector
query
variants

Structs

Column
Indexed
Line
A line of text, consisting of one or more Spans.
Segmented
This struct implements ColumnIndexable, and can instantiate a worker with columns.
Span
Represents a part of a line that is contiguous and where all characters share the same style.
Status
Style
Style lets you control the main characteristics of the displayed elements.
Text
A string split over one or more lines.
Worker
Worker: can instantiate, can push, can get lines and get nth, a view into computation

Enums

WorkerError

Traits

Stylize
An extension trait for styling objects.

Type Aliases

WorkerResults