Module nucleo

Module nucleo 

Re-exports

pub use variants::*;

Modules

injector
query
variants
worker

Structs

Line
A line of text, consisting of one or more Spans.
Span
Represents a part of a line that is contiguous and where all characters share the same style.
Style
Style lets you control the main characteristics of the displayed elements.
Text
A string split over one or more lines.

Traits

Stylize
An extension trait for styling objects.