PickerQuery

Struct PickerQuery 

pub struct PickerQuery { /* private fields */ }

Implementations

Source

impl PickerQuery

pub fn new<I: Iterator<Item = Arc<str>>>( column_names: I, primary_column: usize, ) -> Self

pub fn get(&self, column: &str) -> Option<&Arc<str>>

pub fn primary_column_query(&self) -> Option<&str>

pub fn primary_column_name(&self) -> Option<&str>

pub fn parse(&mut self, input: &str) -> HashMap<Arc<str>, Arc<str>>

pub fn active_column(&self, cursor: usize) -> Option<&Arc<str>>

Finds the column which the cursor is ‘within’ in the last parse.

The cursor is considered to be within a column when it is placed within any of a column’s text. See the active_column_test unit test below for examples.

cursor is a byte index that represents the location of the prompt’s cursor.

pub fn active_column_index(&self, cursor: usize) -> usize

Finds the index of the column which the cursor is ‘within’ in the last parse. Returns the primary column index if no specific column is active at the cursor.

pub fn with_default_column(self, index: usize) -> Self

Sets the default column index.

Warning

This method does not check if the index exists.