pub struct PickerQuery { /* private fields */ }Implementations
Sourceimpl PickerQuery
impl PickerQuery
pub fn new<I: Iterator<Item = Arc<str>>>( column_names: I, primary_column: usize, ) -> Self
pub fn get(&self, column: &str) -> Option<&Arc<str>>
pub fn parse(&mut self, input: &str) -> HashMap<Arc<str>, Arc<str>>
Sourcepub fn active_column(&self, cursor: usize) -> Option<&Arc<str>>
pub fn active_column(&self, cursor: usize) -> Option<&Arc<str>>
Finds the column which the cursor is ‘within’ in the last parse.
The cursor is considered to be within a column when it is placed within any
of a column’s text. See the active_column_test unit test below for examples.
cursor is a byte index that represents the location of the prompt’s cursor.