pub struct Indexed<T> {
pub index: u32,
pub inner: T,
}Fields
index: u32inner: TImplementations
Sourceimpl<T: Clone> Indexed<T>
impl<T: Clone> Indexed<T>
Sourcepub fn identifier(&self) -> (u32, T)
pub fn identifier(&self) -> (u32, T)
Matchmaker requires a way to identify and store selected items from their references in the nucleo matcher. This method simply identifies them by their insertion index and stores the clones of the items.
Sourceimpl<T> Indexed<T>
impl<T> Indexed<T>
Sourcepub fn dummy_identifier(&self) -> (u32, ())
pub fn dummy_identifier(&self) -> (u32, ())
Matchmaker requires a way to identify and store selected items from their references in the nucleo matcher. This method simply identifies them by their insertion index and is intended when the output type is not needed (i.e. externally managed).