Worker

Struct Worker 

pub struct Worker<T>
where T: SSS,
{ /* private fields */ }
Worker: can instantiate, push, and get results. A view into computation.

Additionally, the worker can affect the computation via find and restart.

Implementations

Source

impl<T: SSS> Worker<T>

pub fn default_format_fn<const QUOTE: bool>( &self, blank_format: impl Fn(&T) -> Cow<'_, str> + SSS, ) -> RenderFn<T>

Returns a function which templates a string given an item using the column functions

Source

impl<T: SSS> Worker<Indexed<T>>

pub fn append(&self, items: impl IntoIterator<Item = T>) -> u32

A convenience method to initialize data. Items are indexed starting from the current nucleo item count.

Notes
  • Not concurrent.
  • Subsequent use of IndexedInjector should start from the returned count.
Source

impl<T: Render + SSS> Worker<T>

pub fn new_single_column() -> Self

Create a new worker over items which are displayed in the picker as exactly their as_str representation.

Source

impl<T> Worker<T>
where T: ColumnIndexable + SSS,

pub fn new_indexable<I, S>(column_names: I) -> Self
where I: IntoIterator<Item = S>, S: Into<Arc<str>>,

Create a new worker over indexable items, whose columns correspond to indices according to the relative order of the column names given to this function.

Example
#[derive(Clone)]
pub struct RunAction {
    name: String,
    alias: String,
    desc: String
};

use matchmaker::{Matchmaker, Selector};
use matchmaker::nucleo::{Indexed, Worker, ColumnIndexable};

impl ColumnIndexable for RunAction {
    fn get_str(&self, i: usize) -> std::borrow::Cow<'_, str> {
        if i == 0 {
            &self.name
        } else if i == 1 {
            &self.alias
        } else {
            &self.desc
        }.into()
    }
}

pub fn make_mm(
    items: impl Iterator<Item = RunAction>,
) -> Matchmaker<Indexed<RunAction>, RunAction> {
    let worker = Worker::new_indexable(["name", "alias", "desc"]);
    worker.append(items);
    let selector = Selector::new(Indexed::identifier);
    Matchmaker::new(worker, selector)
}
Source

impl<T> Worker<T>
where T: SSS,

pub fn new( columns: impl IntoIterator<Item = Column<T>>, default_column: usize, ) -> Self

Column names must be distinct!

pub fn injector(&self) -> WorkerInjector<T>

pub fn find(&mut self, line: &str)

pub fn get_nth(&self, n: u32) -> Option<&T>

pub fn new_snapshot(nucleo: &mut Nucleo<T>) -> (&Snapshot<T>, Status)

pub fn raw_results( &self, ) -> impl ExactSizeIterator<Item = &T> + DoubleEndedIterator + '_

pub fn counts(&self) -> (u32, u32)

matched item count, total item count

pub fn restart(&mut self, clear_snapshot: bool)

Source

impl<T: SSS> Worker<T>

pub fn results( &mut self, start: u32, end: u32, width_limits: &[u16], highlight_style: Style, matcher: &mut Matcher, ) -> (WorkerResults<'_, T>, Vec<u16>, Status)

Notes
  • width is at least header width
pub fn exact_column_match(&mut self, column: &str) -> Option<&T>

pub fn format_with<'a>(&'a self, item: &'a T, col: &str) -> Option<Cow<'a, str>>