Worker

Struct Worker 

pub struct Worker<T, C = ()>
where T: MMItem,
{ /* private fields */ }
Worker: can instantiate, can push, can get lines and get nth, a view into computation

Implementations

Source

impl<T, C> Worker<T, C>
where T: MMItem,

pub fn new( columns: impl IntoIterator<Item = Column<T, C>>, default_column: usize, context: C, ) -> Self

pub fn injector(&self) -> WorkerInjector<T, C>

pub fn find(&mut self, line: &str)

pub fn shutdown(&mut self)

pub fn restart(&mut self, clear_snapshot: bool)

pub fn get_nth(&self, n: u32) -> Option<&T>

pub fn new_snapshot(nucleo: &mut Nucleo<T>) -> (&Snapshot<T>, Status)

pub fn raw_results( &self, ) -> impl ExactSizeIterator<Item = &T> + DoubleEndedIterator + '_

pub fn counts(&self) -> (u32, u32)

matched item count, total item count

Source

impl<T: MMItem, C> Worker<T, C>

pub fn results( &mut self, start: u32, end: u32, width_limits: &[u16], highlight_style: Style, matcher: &mut Matcher, ) -> (WorkerResults<'_, T>, Vec<u16>, Status)

Source

impl<T: MMItem> Worker<T>

pub fn make_format_fn<const QUOTE: bool>( &self, blank_format: impl Fn(&T) -> &str + Send + Sync + 'static, ) -> RenderFn<T>

Returns a function which templates a string given an item using the column functions

Source

impl<T: Render + MMItem> Worker<Indexed<T>>

pub fn new_single_column() -> Self

Create a new worker over items which are displayed in the picker as exactly their as_str representation.

Examples found in repository?
examples/frecency.rs (line 5)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
More examples
Hide additional examples
examples/ripgrep.rs (line 5)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
examples/basic.rs (line 8)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let identifier = Indexed::identifier;
11
12    let mm = Matchmaker::new(worker, identifier);
13
14    match mm.pick().await {
15        Ok(v) => {
16            println!("{}", v[0]);
17        }
18        Err(err) => {
19            match err {
20                MatchError::Abort(1) => {
21                    eprintln!("cancelled");
22                }
23                _ => {
24                    eprintln!("Error: {err}");
25                }
26            }
27        }
28    }
29
30    Ok(())
31}
pub fn append(&self, items: impl IntoIterator<Item = T>) -> u32

A convenience method to initialize data. Note that it is clearly unsound to use this concurrently with other workers, or to subsequently push with an IndexedInjector.

Examples found in repository?
examples/frecency.rs (line 7)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
More examples
Hide additional examples
examples/ripgrep.rs (line 7)
4fn main() -> Result<()> {
5    let worker = Worker::new_single_column();
6    let items = vec!["item1", "item2", "item3"];
7    worker.append(items);
8
9    Ok(())
10}
examples/basic.rs (line 9)
5async fn main() -> Result<()> {
6    let items = vec!["item1", "item2", "item3"];
7
8    let worker = Worker::new_single_column();
9    worker.append(items);
10    let identifier = Indexed::identifier;
11
12    let mm = Matchmaker::new(worker, identifier);
13
14    match mm.pick().await {
15        Ok(v) => {
16            println!("{}", v[0]);
17        }
18        Err(err) => {
19            match err {
20                MatchError::Abort(1) => {
21                    eprintln!("cancelled");
22                }
23                _ => {
24                    eprintln!("Error: {err}");
25                }
26            }
27        }
28    }
29
30    Ok(())
31}
Source

impl<T> Worker<T>

pub fn new_indexable<I, S>(column_names: I) -> Self
where I: IntoIterator<Item = S>, S: Into<Arc<str>>,

Create a new worker over indexable items, whose columns as displayed in the picker correspond to indices according to the relative order of the column names given to this function.