Module ui

Module ui 

Structs

DisplayUI
Frame
A consistent view into the terminal state for rendering a single frame.
InputUI
Layout
The primary layout engine for dividing terminal space using constraints and direction.
OverlayUI
PickerUI
PreviewUI
Rect
A rectangular area in the terminal.
ResultsUI
Table
A widget to display data in formatted columns.
UI

Enums

Constraint
A constraint that defines the size of a layout element.
Direction
Defines the direction of a layout.
OverlayEffect

Traits

Overlay

Functions

default_area